@@ -2,6 +2,8 @@ package Test2::API::Context;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use Carp qw/confess croak longmess/;
 use Scalar::Util qw/weaken/;
 use Test2::Util qw/get_tid try pkg_to_file get_tid/;
@@ -55,7 +57,7 @@ sub restore_error_vars {
 
 sub DESTROY {
     return unless $_[0]->{+_IS_CANON} || $_[0]->{+_IS_SPAWN};
-    return if ${$_[0]->{+_ABORTED}};
+    return if $_[0]->{+_ABORTED} && ${$_[0]->{+_ABORTED}};
     my ($self) = @_;
 
     my $hub = $self->{+HUB};
