@@ -2,6 +2,8 @@ package Test2::API::Stack;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use Test2::Hub();
 
 use Carp qw/confess/;
@@ -29,7 +31,6 @@ sub new_hub {
 
         my $ipc = Test2::API::test2_ipc();
         if ($ipc && !$hub->ipc && !exists($params{ipc})) {
-            local $!;
             $hub->set_ipc($ipc);
             $ipc->add_hub($hub->hid);
         }
