@@ -2,15 +2,16 @@ package Test2::Event::Bail;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use base 'Test2::Event';
 use Test2::Util::HashBase qw{reason};
 
-sub update_state {
+sub callback {
     my $self = shift;
-    my ($state) = @_;
+    my ($hub) = @_;
 
-    $state->set_bailed_out($self);
-    $state->bump_fail;
+    $hub->set_bailed_out($self);
 }
 
 # Make sure the tests terminate
