@@ -2,8 +2,10 @@ package Test2::Event::Diag;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use base 'Test2::Event';
-use Test2::Util::HashBase qw{message todo};
+use Test2::Util::HashBase qw/message/;
 
 sub init {
     $_[0]->{+MESSAGE} = 'undef' unless defined $_[0]->{+MESSAGE};
