@@ -2,17 +2,11 @@ package Test2::Event::Exception;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use base 'Test2::Event';
 use Test2::Util::HashBase qw{error};
 
-sub update_state {
-    my $self = shift;
-    my ($state) = @_;
-
-    $state->bump_fail;
-    return undef;
-}
-
 sub causes_fail { 1 }
 
 1;
