@@ -2,9 +2,11 @@ package Test2::Event::Ok;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use base 'Test2::Event';
 use Test2::Util::HashBase qw{
-    pass effective_pass name diag allow_bad_name todo diag_todo
+    pass effective_pass name todo
 };
 
 sub init {
@@ -12,41 +14,24 @@ sub init {
 
     # Do not store objects here, only true or false
     $self->{+PASS} = $self->{+PASS} ? 1 : 0;
+    $self->{+EFFECTIVE_PASS} = $self->{+PASS} || (defined($self->{+TODO}) ? 1 : 0);
 
-    $self->{+EFFECTIVE_PASS} = ($self->{+PASS} || defined($self->{+TODO})) ? 1 : 0;
-
-    return if $self->{+ALLOW_BAD_NAME};
-    my $name = $self->{+NAME} || return;
+    my $name = $self->{+NAME} or return;
     return unless index($name, '#') != -1 || index($name, "\n") != -1;
     $self->trace->throw("'$name' is not a valid name, names must not contain '#' or newlines.")
 }
 
-sub default_diag {
-    my $self = shift;
-
-    return if $self->{+PASS};
-
-    my $name  = $self->{+NAME};
-    my $trace = $self->{+TRACE};
-    my $pass  = $self->{+PASS};
-    my $todo  = defined($self->{+TODO});
-
-    my $msg = $todo ? "Failed (TODO)" : "Failed";
-    my $prefix = $ENV{HARNESS_ACTIVE} && !$ENV{HARNESS_IS_VERBOSE} ? "\n" : "";
-
-    my $debug = $trace ? $trace->debug : "[No trace info available]";
-
-    if (defined $name) {
-        $msg = qq[$prefix$msg test '$name'\n$debug.];
+{
+    no warnings 'redefine';
+    sub set_todo {
+        my $self = shift;
+        my ($todo) = @_;
+        $self->{+TODO} = $todo;
+        $self->{+EFFECTIVE_PASS} = defined($todo) ? 1 : $self->{+PASS};
     }
-    else {
-        $msg = qq[$prefix$msg test $debug.];
-    }
-
-    return $msg;
 }
 
-sub update_state { $_[1]->bump($_[0]->{+EFFECTIVE_PASS}) }
+sub increments_count { 1 };
 
 sub causes_fail { !$_[0]->{+EFFECTIVE_PASS} }
 
@@ -106,14 +91,10 @@ Name of the test.
 
 An arrayref full of diagnostics strings to print in the event of a failure.
 
-B<Note:> This does not have anything by default, the C<default_diag()> method
-can be used to generate the basic diagnostics message which you may push into
-this arrayref.
-
 =item $b = $e->effective_pass
 
-This is the true/false value of the test after TODO, SKIP, and similar
-modifiers are taken into account.
+This is the true/false value of the test after TODO and similar modifiers are
+taken into account.
 
 =item $b = $e->allow_bad_name
 
@@ -122,19 +103,6 @@ confuse a TAP parser.
 
 =back
 
-=head1 METHODS
-
-=over 4
-
-=item $string = $e->default_diag()
-
-This generates the default diagnostics string:
-
-    # Failed test 'Some Test'
-    # at t/foo.t line 42.
-
-=back
-
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
