@@ -2,6 +2,8 @@ package Test2::Event::Plan;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use base 'Test2::Event';
 use Test2::Util::HashBase qw{max directive reason};
 
@@ -34,12 +36,15 @@ sub init {
     }
 }
 
-sub update_state {
+sub callback {
     my $self = shift;
-    my ($state) = @_;
+    my ($hub) = @_;
 
-    $state->plan($self->{+DIRECTIVE} || $self->{+MAX});
-    $state->set_skip_reason($self->{+REASON});
+    $hub->plan($self->{+DIRECTIVE} || $self->{+MAX});
+
+    return unless $self->{+DIRECTIVE};
+
+    $hub->set_skip_reason($self->{+REASON} || 1) if $self->{+DIRECTIVE} eq 'SKIP';
 }
 
 sub terminate {
@@ -49,13 +54,6 @@ sub terminate {
     return undef;
 }
 
-sub global {
-    my $self = shift;
-    return 0 unless $self->{+DIRECTIVE};
-    return 0 unless $self->{+DIRECTIVE} eq 'SKIP';
-    return 1;
-}
-
 1;
 
 __END__
