@@ -2,6 +2,8 @@ package Test2::Event::Skip;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use base 'Test2::Event::Ok';
 use Test2::Util::HashBase qw{reason};
 
@@ -11,8 +13,6 @@ sub init {
     $self->{+EFFECTIVE_PASS} = 1;
 }
 
-sub update_state { $_[1]->bump(1) }
-
 sub causes_fail { 0 }
 
 1;
