@@ -2,8 +2,7 @@ package Test2::Event::Subtest;
 use strict;
 use warnings;
 
-use Scalar::Util qw/blessed/;
-use Carp qw/confess/;
+our $VERSION = '0.000026';
 
 use base 'Test2::Event::Ok';
 use Test2::Util::HashBase qw{subevents buffered};
