@@ -2,6 +2,8 @@ package Test2::Formatter::TAP;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use Test2::Util::HashBase qw{
     no_numbers handles _encoding
 };
@@ -103,7 +105,6 @@ sub write {
 sub _open_handles {
     my $self = shift;
 
-    local $!;
     open( my $out, ">&STDOUT" ) or die "Can't dup STDOUT:  $!";
     open( my $err, ">&STDERR" ) or die "Can't dup STDERR:  $!";
 
