@@ -2,6 +2,8 @@ package Test2::Hub;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use Carp qw/carp croak confess/;
 use Test2::Util qw/get_tid/;
 
@@ -248,7 +250,7 @@ sub send {
     my $ipc = $self->{+IPC} || return $self->process($e);
 
     if($e->global) {
-        $ipc->send('GLOBAL', $e);
+        $ipc->send($self->{+HID}, $e, 'GLOBAL');
         return $self->process($e);
     }
 
