@@ -2,6 +2,8 @@ package Test2::IPC::Driver;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use Carp qw/confess longmess/;
 use Test2::Util::HashBase qw{no_fatal};
 
@@ -15,6 +17,8 @@ sub import {
     test2_ipc_add_driver($class);
 }
 
+sub use_shm { 0 }
+
 for my $meth (qw/send cull add_hub drop_hub waiting is_viable/) {
     no strict 'refs';
     *$meth = sub {
@@ -84,6 +88,11 @@ error.
 This is the same as C<< $ipc->abort($msg) >> except that it uses
 C<Carp::longmess> to add a stack trace to the message.
 
+=item $false = $self->use_shm
+
+The base class always returns false for this method. You may override it if you
+wish to use the SHM made avilable in L<Test2::API>/L<Test2::API::Instance>.
+
 =back
 
 =head1 LOADING DRIVERS
@@ -127,9 +136,13 @@ load it too late for it to be effective.
 
     sub send {
         my $self = shift;
-        my ($hid, $e) = @_;
+        my ($hid, $e, $global) = @_;
 
         ... # Send the event to the proper hub.
+
+        # If you are using the SHM you should notify other procs/threads that
+        # there is a pending event.
+        Test2::API::test2_ipc_set_pending($uniq_val);
     }
 
     sub cull {
@@ -188,6 +201,8 @@ to enforce).
 
 =item $ipc->send($hid, $event);
 
+=item $ipc->send($hid, $event, $global);
+
 Used to send events from the current process/thread to the specified hub in its
 process+thread.
 
@@ -196,8 +211,15 @@ process+thread.
         my ($hid, $e) = @_;
 
         ... # Send the event to the proper hub.
+
+        # If you are using the SHM you should notify other procs/threads that
+        # there is a pending event.
+        Test2::API::test2_ipc_set_pending($uniq_val);
     }
 
+If C<$global> is true then the driver should send the event to all hubs in all
+processes and threads.
+
 =item @events = $ipc->cull($hid)
 
 Used to collect events that have been sent to the specified hub.
@@ -225,6 +247,21 @@ child processes and threads to complete.
 
 =back
 
+=head2 METHODS SUBCLASSES MAY IMPLEMENT OR OVERRIDE
+
+=over 4
+
+=item $bool = $ipc->use_shm()
+
+True if you want to make use of the L<Test2::API>/L<Test2::API::Instance> SHM.
+
+=item $bites = $ipc->shm_size()
+
+Use this to customize the size of the shm space. There are no guarentees about
+what the size will be if you do not implement this.
+
+=back
+
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
