@@ -2,6 +2,8 @@ package Test2::Util::Trace;
 use strict;
 use warnings;
 
+our $VERSION = '0.000026';
+
 use Test2::Util qw/get_tid/;
 
 use Carp qw/confess/;
@@ -12,8 +14,8 @@ sub init {
     confess "The 'frame' attribute is required"
         unless $_[0]->{+FRAME};
 
-    $_[0]->{+PID} ||= $$;
-    $_[0]->{+TID} ||= get_tid();
+    $_[0]->{+PID} = $$        unless defined $_[0]->{+PID};
+    $_[0]->{+TID} = get_tid() unless defined $_[0]->{+TID};
 }
 
 sub snapshot { bless {%{$_[0]}}, __PACKAGE__ };
